@@ -2,13 +2,15 @@
 import json
 import logging
 
-from acme.magic_typing import Any, Dict  # pylint: disable=unused-import, no-name-in-module
-
+from acme.magic_typing import Any  # pylint: disable=unused-import, no-name-in-module
+from acme.magic_typing import Dict  # pylint: disable=unused-import, no-name-in-module
 from certbot import errors
+from certbot.compat import filesystem
 from certbot.compat import os
 
 logger = logging.getLogger(__name__)
 
+
 class PluginStorage(object):
     """Class implementing storage functionality for plugins"""
 
@@ -84,9 +86,10 @@ class PluginStorage(object):
             logger.error(errmsg)
             raise errors.PluginStorageError(errmsg)
         try:
-            with os.fdopen(os.open(self._storagepath,
-                                   os.O_WRONLY | os.O_CREAT | os.O_TRUNC,
-                                   0o600), 'w') as fh:
+            with os.fdopen(filesystem.open(
+                    self._storagepath,
+                    os.O_WRONLY | os.O_CREAT | os.O_TRUNC,
+                    0o600), 'w') as fh:
                 fh.write(serialized)
         except IOError as e:
             errmsg = "Could not write PluginStorage data to file {0} : {1}".format(
